/* This file was generated by syncqt. */
#ifndef QT_QT3DINPUT_VERSION_H
#define QT_QT3DINPUT_VERSION_H

#define QT3DINPUT_VERSION_STR "6.6.3"

#define QT3DINPUT_VERSION 0x060603

#endif // QT_QT3DINPUT_VERSION_H
